Package: nosoi
Type: Package
Title: A Forward Agent-Based Transmission Chain Simulator
Version: 1.1.2
Authors@R: c(person("Sebastian", "Lequime", email = "sebastian.lequime@gmail.com",
                  role = c("aut", "cre"), comment = c(ORCID = "0000-0002-3140-0651")),
                  person("Paul", "Bastide", email = "paul.bastide@umontpellier.fr",
                  role = "aut", comment = c(ORCID = "0000-0002-8084-9893")),
                  person("Simon", "Dellicour", email = "simon.dellicour@kuleuven.be",
                  role = "aut", comment = c(ORCID = "0000-0001-9558-1052")),
                  person("Philippe", "Lemey", email = "philippe.lemey@kuleuven.be",
                  role = "aut", comment = c(ORCID = "0000-0003-2826-5353")),
                  person("Guy", "Baele", email = "guy.baele@kuleuven.be",
                  role = "aut", comment = c(ORCID = "0000-0002-1915-7732")),
                  person("Thijs", "Janzen", email = "t.janzen@rug.nl",
                  role = "ctb", comment = c(ORCID = "0000-0002-4162-1140")))
Description: The aim of 'nosoi' (pronounced no.si) is to provide a flexible agent-based stochastic transmission chain/epidemic simulator (Lequime et al. Methods in Ecology and Evolution 11:1002-1007). It is named after the daimones of plague, sickness and disease that escaped Pandora's jar in the Greek mythology. 'nosoi' is able to take into account the influence of multiple variable on the transmission process (e.g. dual-host systems (such as arboviruses), within-host viral dynamics, transportation, population structure), alone or taken together, to create complex but relatively intuitive epidemiological simulations.
URL: https://github.com/slequime/nosoi,
        https://slequime.github.io/nosoi/
BugReports: https://github.com/slequime/nosoi/issues
Language: en-US
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.2.3
biocViews:
Depends: data.table (>= 1.12.0), R (>= 3.5.0)
Imports: stats (>= 3.5.2), methods (>= 3.5.2), raster (>= 2.8-19)
Suggests: testthat (>= 2.1.0), knitr, rmarkdown, igraph, ggplot2,
        ggnetwork, intergraph, viridis, gifski, png, gganimate, ape (>=
        5.3), tidytree (>= 0.3.3), treeio (>= 1.14.0), ggtree (>=
        2.4.0), magrittr (>= 1.5), dplyr (>= 0.8.0), covr
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2024-02-09 12:29:40 UTC; slequime
Author: Sebastian Lequime [aut, cre] (<https://orcid.org/0000-0002-3140-0651>),
  Paul Bastide [aut] (<https://orcid.org/0000-0002-8084-9893>),
  Simon Dellicour [aut] (<https://orcid.org/0000-0001-9558-1052>),
  Philippe Lemey [aut] (<https://orcid.org/0000-0003-2826-5353>),
  Guy Baele [aut] (<https://orcid.org/0000-0002-1915-7732>),
  Thijs Janzen [ctb] (<https://orcid.org/0000-0002-4162-1140>)
Maintainer: Sebastian Lequime <sebastian.lequime@gmail.com>
Repository: CRAN
Date/Publication: 2024-02-09 12:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 23:10:44 UTC; unix
