# Generated by roxygen2: do not edit by hand

S3method(print,nosoiSim)
S3method(summary,nosoiSim)
export(dualContinuous)
export(dualDiscrete)
export(dualNone)
export(getCumulative)
export(getDynamic)
export(getHostData)
export(getR0)
export(getTableHosts)
export(getTableState)
export(getTransmissionTree)
export(nosoiSim)
export(nosoiSummary)
export(sampleTransmissionTree)
export(sampleTransmissionTreeFromExiting)
export(singleContinuous)
export(singleDiscrete)
export(singleNone)
import(data.table)
importFrom(methods,formalArgs)
importFrom(methods,substituteDirect)
importFrom(stats,rnorm)
importFrom(stats,runif)
